==> libsbml-3.3.2-src.zip: libsbml-3.3.2/src/bindings/java/test/org/sbml/libsbml/test/sbml/TestInitialAssignment.java <==
/*
 *
 * @file    TestInitialAssignment.java
 * @brief   SBML InitialAssignment unit tests
 *
 * @author  Akiya Jouraku (Java conversion)
 * @author  Sarah Keating 
 *
 * $Id: TestInitialAssignment.java 8704 2009-01-04 02:26:05Z mhucka $
 * $HeadURL: https://sbml.svn.sourceforge.net/svnroot/sbml/trunk/libsbml/src/bindings/java/test/org/sbml/libsbml/test/sbml/TestInitialAssignment.java $
 *
 * This test file was converted from src/sbml/test/TestInitialAssignment.c
 * with the help of conversion sciprt (ctest_converter.pl).
 *
 *<!---------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright 2005-2008 California Institute of Technology.
 * Copyright 2002-2005 California Institute of Technology and
 *                     Japan Science and Technology Corporation.
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 *--------------------------------------------------------------------------->*/


package org.sbml.libsbml.test.sbml;

import org.sbml.libsbml.*;

import java.io.File;
import java.lang.AssertionError;

public class TestInitialAssignment {

  static void assertTrue(boolean condition) throws AssertionError
  {
    if (condition == true)
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertEquals(Object a, Object b) throws AssertionError
  {
    if ( (a == null) && (b == null) )
    {
      return;
    }
    else if (a.equals(b))
    {
      return;
    }

    throw new AssertionError();
  }

  static void assertNotEquals(Object a, Object b) throws AssertionError
  {
    if ( (a == null) && (b == null) )
    {
      throw new AssertionError();
    }
    else if (a.equals(b))
    {
      throw new AssertionError();
    }
  }

  static void assertEquals(boolean a, boolean b) throws AssertionError
  {
    if ( a == b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertNotEquals(boolean a, boolean b) throws AssertionError
  {
    if ( a != b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertEquals(int a, int b) throws AssertionError
  {
    if ( a == b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertNotEquals(int a, int b) throws AssertionError
  {
    if ( a != b )
    {
      return;
    }
    throw new AssertionError();
  }
  private InitialAssignment IA;

  protected void setUp() throws Exception
  {
    IA = new  InitialAssignment();
    if (IA == null);
    {
    }
  }

  protected void tearDown() throws Exception
  {
    IA = null;
  }

  public void test_InitialAssignment_create()
  {
    assertTrue( IA.getTypeCode() == libsbml.SBML_INITIAL_ASSIGNMENT );
    assertTrue( IA.getMetaId().equals("") == true );
    assertTrue( IA.getNotes() == null );
    assertTrue( IA.getAnnotation() == null );
    assertTrue( IA.getSymbol().equals("") == true );
    assertTrue( IA.getMath() == null );
  }

  public void test_InitialAssignment_createWith()
  {
    InitialAssignment ia = new  InitialAssignment("k");
    assertTrue( ia.getTypeCode() == libsbml.SBML_INITIAL_ASSIGNMENT );
    assertTrue( ia.getMetaId().equals("") == true );
    assertTrue( ia.getNotes() == null );
    assertTrue( ia.getAnnotation() == null );
    assertEquals( false, ia.isSetMath() );
    assertTrue(ia.getSymbol().equals( "k"));
    assertEquals( true, ia.isSetSymbol() );
    ia = null;
  }

  public void test_InitialAssignment_createWithLevelVersionAndNamespace()
  {
    XMLNamespaces xmlns = new  XMLNamespaces();
    xmlns.add( "http://www.sbml.org", "sbml");
    InitialAssignment object = new  InitialAssignment(2,3,xmlns);
    assertTrue( object.getTypeCode() == libsbml.SBML_INITIAL_ASSIGNMENT );
    assertTrue( object.getMetaId().equals("") == true );
    assertTrue( object.getNotes() == null );
    assertTrue( object.getAnnotation() == null );
    assertTrue( object.getLevel() == 2 );
    assertTrue( object.getVersion() == 3 );
    assertTrue( object.getNamespaces() != null );
    assertTrue( object.getNamespaces().getLength() == 1 );
    object = null;
  }

  public void test_InitialAssignment_free_NULL()
  {
  }

  public void test_InitialAssignment_setMath()
  {
    ASTNode math = libsbml.parseFormula("2 * k");
    String formula;
    ASTNode math1;
    IA.setMath(math);
    math1 = IA.getMath();
    assertTrue( math1 != null );
    formula = libsbml.formulaToString(math1);
    assertTrue( formula != null );
    assertTrue(formula.equals( "2 * k"));
    assertTrue( !IA.getMath().equals(math) );
    assertEquals( true, IA.isSetMath() );
    IA.setMath(IA.getMath());
    math1 = IA.getMath();
    assertTrue( math1 != null );
    formula = libsbml.formulaToString(math1);
    assertTrue( formula != null );
    assertTrue(formula.equals( "2 * k"));
    assertTrue( !IA.getMath().equals(math) );
    IA.setMath(null);
    assertEquals( false, IA.isSetMath() );
    if (IA.getMath() != null);
    {
    }
    math = null;
  }

  public void test_InitialAssignment_setSymbol()
  {
    String Symbol =  "k2";;
    IA.setSymbol(Symbol);
    assertTrue(IA.getSymbol().equals(Symbol));
    assertEquals( true, IA.isSetSymbol() );
    if (IA.getSymbol() == Symbol);
    {
    }
    IA.setSymbol(IA.getSymbol());
    assertTrue(IA.getSymbol().equals(Symbol));
    IA.setSymbol("");
    assertEquals( false, IA.isSetSymbol() );
    if (IA.getSymbol() != null);
    {
    }
  }

  /**
   * Loads the SWIG-generated libSBML Java module when this class is
   * loaded, or reports a sensible diagnostic message about why it failed.
   */
  static
  {
    String varname;
    String shlibname;

    if (System.getProperty("mrj.version") != null)
    {
      varname = "DYLD_LIBRARY_PATH";    // We're on a Mac.
      shlibname = "libsbmlj.jnilib and/or libsbml.dylib";
    }
    else
    {
      varname = "LD_LIBRARY_PATH";      // We're not on a Mac.
      shlibname = "libsbmlj.so and/or libsbml.so";
    }

    try
    {
      System.loadLibrary("sbmlj");
      // For extra safety, check that the jar file is in the classpath.
      Class.forName("org.sbml.libsbml.libsbml");
    }
    catch (SecurityException e)
    {
      e.printStackTrace();
      System.err.println("Could not load the libSBML library files due to a"+
                         " security exception.\n");
      System.exit(1);
    }
    catch (UnsatisfiedLinkError e)
    {
      e.printStackTrace();
      System.err.println("Error: could not link with the libSBML library files."+
                         " It is likely\nyour " + varname +
                         " environment variable does not include the directories\n"+
                         "containing the " + shlibname + " library files.\n");
      System.exit(1);
    }
    catch (ClassNotFoundException e)
    {
      e.printStackTrace();
      System.err.println("Error: unable to load the file libsbmlj.jar."+
                         " It is likely\nyour -classpath option and CLASSPATH" +
                         " environment variable\n"+
                         "do not include the path to libsbmlj.jar.\n");
      System.exit(1);
    }
  }
}

==> libsbml-4.0.0-src.zip: libsbml-4.0.0/src/bindings/java/test/org/sbml/libsbml/test/sbml/TestInitialAssignment.java <==
/*
 *
 * @file    TestInitialAssignment.java
 * @brief   SBML InitialAssignment unit tests
 *
 * @author  Akiya Jouraku (Java conversion)
 * @author  Sarah Keating 
 *
 * $Id: TestInitialAssignment.java 10068 2009-08-21 18:54:20Z ajouraku $
 * $HeadURL: https://sbml.svn.sourceforge.net/svnroot/sbml/branches/libsbml-4/src/bindings/java/test/org/sbml/libsbml/test/sbml/TestInitialAssignment.java $
 *
 * This test file was converted from src/sbml/test/TestInitialAssignment.c
 * with the help of conversion sciprt (ctest_converter.pl).
 *
 *<!---------------------------------------------------------------------------
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
 * Copyright 2005-2009 California Institute of Technology.
 * Copyright 2002-2005 California Institute of Technology and
 *                     Japan Science and Technology Corporation.
 * 
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation.  A copy of the license agreement is provided
 * in the file named "LICENSE.txt" included with this software distribution
 * and also available online as http://sbml.org/software/libsbml/license.html
 *--------------------------------------------------------------------------->*/


package org.sbml.libsbml.test.sbml;

import org.sbml.libsbml.*;

import java.io.File;
import java.lang.AssertionError;

public class TestInitialAssignment {

  static void assertTrue(boolean condition) throws AssertionError
  {
    if (condition == true)
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertEquals(Object a, Object b) throws AssertionError
  {
    if ( (a == null) && (b == null) )
    {
      return;
    }
    else if ( (a == null) || (b == null) )
    {
      throw new AssertionError();
    }
    else if (a.equals(b))
    {
      return;
    }

    throw new AssertionError();
  }

  static void assertNotEquals(Object a, Object b) throws AssertionError
  {
    if ( (a == null) && (b == null) )
    {
      throw new AssertionError();
    }
    else if ( (a == null) || (b == null) )
    {
      return;
    }
    else if (a.equals(b))
    {
      throw new AssertionError();
    }
  }

  static void assertEquals(boolean a, boolean b) throws AssertionError
  {
    if ( a == b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertNotEquals(boolean a, boolean b) throws AssertionError
  {
    if ( a != b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertEquals(int a, int b) throws AssertionError
  {
    if ( a == b )
    {
      return;
    }
    throw new AssertionError();
  }

  static void assertNotEquals(int a, int b) throws AssertionError
  {
    if ( a != b )
    {
      return;
    }
    throw new AssertionError();
  }
  private InitialAssignment IA;

  protected void setUp() throws Exception
  {
    IA = new  InitialAssignment(2,4);
    if (IA == null);
    {
    }
  }

  protected void tearDown() throws Exception
  {
    IA = null;
  }

  public void test_InitialAssignment_create()
  {
    assertTrue( IA.getTypeCode() == libsbml.SBML_INITIAL_ASSIGNMENT );
    assertTrue( IA.getMetaId().equals("") == true );
    assertTrue( IA.getNotes() == null );
    assertTrue( IA.getAnnotation() == null );
    assertTrue( IA.getSymbol().equals("") == true );
    assertTrue( IA.getMath() == null );
  }

  public void test_InitialAssignment_createWithNS()
  {
    XMLNamespaces xmlns = new  XMLNamespaces();
    xmlns.add( "http://www.sbml.org", "testsbml");
    SBMLNamespaces sbmlns = new  SBMLNamespaces(2,3);
    sbmlns.addNamespaces(xmlns);
    InitialAssignment object = new  InitialAssignment(sbmlns);
    assertTrue( object.getTypeCode() == libsbml.SBML_INITIAL_ASSIGNMENT );
    assertTrue( object.getMetaId().equals("") == true );
    assertTrue( object.getNotes() == null );
    assertTrue( object.getAnnotation() == null );
    assertTrue( object.getLevel() == 2 );
    assertTrue( object.getVersion() == 3 );
    assertTrue( object.getNamespaces() != null );
    assertTrue( object.getNamespaces().getLength() == 2 );
    object = null;
  }

  public void test_InitialAssignment_free_NULL()
  {
  }

  public void test_InitialAssignment_setMath()
  {
    ASTNode math = libsbml.parseFormula("2 * k");
    String formula;
    ASTNode math1;
    IA.setMath(math);
    math1 = IA.getMath();
    assertTrue( math1 != null );
    formula = libsbml.formulaToString(math1);
    assertTrue( formula != null );
    assertTrue(formula.equals( "2 * k"));
    assertTrue( !IA.getMath().equals(math) );
    assertEquals( true, IA.isSetMath() );
    IA.setMath(IA.getMath());
    math1 = IA.getMath();
    assertTrue( math1 != null );
    formula = libsbml.formulaToString(math1);
    assertTrue( formula != null );
    assertTrue(formula.equals( "2 * k"));
    assertTrue( !IA.getMath().equals(math) );
    IA.setMath(null);
    assertEquals( false, IA.isSetMath() );
    if (IA.getMath() != null);
    {
    }
    math = null;
  }

  public void test_InitialAssignment_setSymbol()
  {
    String Symbol =  "k2";;
    IA.setSymbol(Symbol);
    assertTrue(IA.getSymbol().equals(Symbol));
    assertEquals( true, IA.isSetSymbol() );
    if (IA.getSymbol() == Symbol);
    {
    }
    IA.setSymbol(IA.getSymbol());
    assertTrue(IA.getSymbol().equals(Symbol));
    IA.setSymbol("");
    assertEquals( false, IA.isSetSymbol() );
    if (IA.getSymbol() != null);
    {
    }
  }

  /**
   * Loads the SWIG-generated libSBML Java module when this class is
   * loaded, or reports a sensible diagnostic message about why it failed.
   */
  static
  {
    String varname;
    String shlibname;

    if (System.getProperty("mrj.version") != null)
    {
      varname = "DYLD_LIBRARY_PATH";    // We're on a Mac.
      shlibname = "libsbmlj.jnilib and/or libsbml.dylib";
    }
    else
    {
      varname = "LD_LIBRARY_PATH";      // We're not on a Mac.
      shlibname = "libsbmlj.so and/or libsbml.so";
    }

    try
    {
      System.loadLibrary("sbmlj");
      // For extra safety, check that the jar file is in the classpath.
      Class.forName("org.sbml.libsbml.libsbml");
    }
    catch (SecurityException e)
    {
      e.printStackTrace();
      System.err.println("Could not load the libSBML library files due to a"+
                         " security exception.\n");
      System.exit(1);
    }
    catch (UnsatisfiedLinkError e)
    {
      e.printStackTrace();
      System.err.println("Error: could not link with the libSBML library files."+
                         " It is likely\nyour " + varname +
                         " environment variable does not include the directories\n"+
                         "containing the " + shlibname + " library files.\n");
      System.exit(1);
    }
    catch (ClassNotFoundException e)
    {
      e.printStackTrace();
      System.err.println("Error: unable to load the file libsbmlj.jar."+
                         " It is likely\nyour -classpath option and CLASSPATH" +
                         " environment variable\n"+
                         "do not include the path to libsbmlj.jar.\n");
      System.exit(1);
    }
  }
}
